#
# spec file for package python-openwrt-luci-rpc
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-openwrt-luci-rpc
Version:        1.1.16
Release:        1.1
Summary:        Module for interacting with OpenWrt Luci RPC interface
License:        Apache-2.0
URL:            https://github.com/fbradyirl/openwrt-luci-rpc
Source:         https://files.pythonhosted.org/packages/source/o/openwrt-luci-rpc/openwrt-luci-rpc-%{version}.tar.gz
BuildRequires:  %{python_module click >= 6.0}
BuildRequires:  %{python_module packaging >= 19.1}
BuildRequires:  %{python_module requests >= 2.21}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-click >= 6.0
Requires:       python-packaging >= 19.1
Requires:       python-requests >= 2.21
BuildArch:      noarch
%python_subpackages

%description
Module for interacting with OpenWrt Luci RPC interface. You need to have 'luci-mod-rpc'
installed on your openwrt based router.

-  Allows you to use the Luci RPC interface to fetch connected devices
   on your OpenWrt based router.
-  Supports 15.X & 17.X & 18.X or newer releases of OpenWrt.

https://openwrt-luci-rpc.readthedocs.io

%prep
%autosetup -p1 -n openwrt-luci-rpc-%{version}
# do not harcode versions
sed -i -e 's:==:>=:g' setup.py

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%python_expand PYTHONPATH=%{buildroot}%{$python_sitelib} $python -m unittest discover -v

%files %{python_files}
%license LICENSE
%doc AUTHORS.rst CONTRIBUTING.rst HISTORY.rst README.rst
%{python_sitelib}/openwrt_luci_rpc*

%changelog
* Thu Jul 20 2023 Antonio Teixeira <antonio.teixeira@suse.com>
- Update to 1.1.16 (2023-03-09)
  * Downgrade logging level for version detection (#57)
  * Modify test
- Drop fix-tests.patch
* Mon Mar  6 2023 Daniel Garcia <daniel.garcia@suse.com>
- Add fix-tests.patch to make tests work with latest packaging module
* Wed Oct  5 2022 Daniel Garcia <daniel.garcia@suse.com>
- Update to 1.1.12 (2022-09-11)
  * Includes latest fixes to support newer versions of OpenWrt
* Tue Oct  4 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to 1.1.11 (2021-03-21)
  * Add rst-linter pre-commit hook to prevent committing errors to HISTORY.rst #50
- Update to 1.1.10 (2021-03-21)
  * Also trigger the Github Actions on push of tags (#49)
- Update to 1.1.9 (2021-03-21)
  * Publish to pypi only once in github actions (#47)
- Update to 1.1.8 (2021-03-12)
  * Support newer openwrt snapshot versions (#45)
  * Fix tox in github actions and also test py38 (#46)
- Update to 1.1.7 (2020-12-08)
  * Switch pipeline to Github actions
- Update to 1.1.6 (2020-09-01)
  * Fixes home-assistant/core/issues/38870, home-assistant/core/issues/39498
  * Fixes fbradyirl/openwrt-luci-rpc/issues/33
- Update to 1.1.5 (2020-09-01)
  * Unpin pip versions. Allow higher. Fixes #42 https://github.com/fbradyirl/openwrt-luci-rpc/issues/42
* Tue May 26 2020 Tomáš Chvátal <tchvatal@suse.com>
- Format with spec-cleaner
- Fix tests
- Fix dependencies
* Mon May 25 2020 Adrian Schröter <adrian@suse.de>
- initial package version 1.1.3
